@@ -148,15 +148,15 @@ class EventsRuleToLambda(
 
         jsii.create(EventsRuleToLambda, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
-        return jsii.get(self, "eventsRule")
+        return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return jsii.get(self, "lambdaFunction")
+        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
 
 @jsii.data_type(
@@ -203,7 +203,7 @@ class EventsRuleToLambdaProps:
         """
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_events.RuleProps, result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -212,7 +212,7 @@ class EventsRuleToLambdaProps:
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def lambda_function_props(
@@ -223,7 +223,7 @@ class EventsRuleToLambdaProps:
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
